#ifndef ALARM_H
#define ALARM_H

#include "fly-date-shared_global.h"

#include <QObject>
#include <QDateTime>
#include <QVariantList>

namespace FlyDate {

class FLYDATESHAREDSHARED_EXPORT Alarm : public QObject
{
    Q_OBJECT
    Q_PROPERTY(bool active      READ active WRITE setActive NOTIFY activeChanged)
    Q_PROPERTY(QVariantList dow READ dow    WRITE setDow    NOTIFY dowChanged)
    Q_PROPERTY(QString name     READ name   WRITE setName   NOTIFY nameChanged)
    Q_PROPERTY(QTime time       READ time   WRITE setTime   NOTIFY timeChanged)
    Q_PROPERTY(int delay        READ delay  WRITE setDelay  NOTIFY delayChanged)
    Q_PROPERTY(QString soundPath READ soundPath WRITE setSoundPath NOTIFY soundPathChanged)

public:
    explicit Alarm(const QString &id, QObject *parent = nullptr);

    QString id() const;
    bool active() const;
    void setActive(bool active);

    QVariantList dow() const;
    void setDow(QVariantList dow);

    QString name() const;
    void setName(const QString &name);

    QTime time() const;
    void setTime(const QTime &time);

    QString soundPath() const;
    void setSoundPath(const QString &soundPath);

    QDateTime dateTime() const;
    void setDateTime(const QDateTime &dt);

    bool isSingleShot() const;
    QDateTime closestAlarm() const;

    QString getCronString(const QString &key) const;

    int delay() const;
    void setDelay(int delay);

signals:
    void activeChanged();
    void dowChanged();
    void nameChanged();
    void timeChanged();
    void soundPathChanged();
    void delayChanged();

private:
    QString m_id;
    QVariantList m_dow;
    bool    m_active {false};
    int     m_delay {5}; // min
    QString m_name;
    QDateTime m_datetime;
    QString m_soundPath;
};

}

#endif // ALARM_H
